"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const util_1 = require("../utility/util");
const dependencies_1 = require("../utility/dependencies");
// You don't have to export the function as default. You can also have more than one rule factory
// per file.
function bootstrapSchematics(_options) {
    return (tree, _context) => {
        console.log(_options);
        return schematics_1.chain([
            updateDependencies(),
            installDependencies(),
            _options.removeStyles ? removeFiles() : schematics_1.noop(),
            addBootstrapFiles(),
            modifyAngularJson(_options)
        ])(tree, _context);
    };
}
exports.bootstrapSchematics = bootstrapSchematics;
function removeFiles() {
    return (tree, context) => {
        context.logger.debug("Removing styles default file");
        if (tree.exists("./src/styles.scss")) {
            tree.delete("./src/styles.scss");
        }
        if (tree.exists("./src/styles.css")) {
            tree.delete("./src/styles.css");
        }
    };
}
function updateDependencies() {
    // let removeDependencies: Observable<Tree>;
    return (tree, context) => {
        context.logger.debug("Updating dependencies...");
        context.addTask(new tasks_1.NodePackageInstallTask());
        const addDependencies = rxjs_1.of("bootstrap", "@ng-bootstrap/ng-bootstrap", "@angular/localize").pipe(operators_1.concatMap((packageName) => util_1.getLatestNodeVersion(packageName)), operators_1.map((packageFromRegistry) => {
            const { name, version } = packageFromRegistry;
            context.logger.debug(`Adding ${name}:${version} to ${dependencies_1.NodeDependencyType.Dev}`);
            dependencies_1.addPackageJsonDependency(tree, {
                type: dependencies_1.NodeDependencyType.Dev,
                name,
                version
            });
            return tree;
        }));
        return rxjs_1.concat(addDependencies);
    };
}
function installDependencies() {
    return (tree, _context) => {
        _context.addTask(new tasks_1.NodePackageInstallTask());
        _context.logger.debug('✅️ Dependencies installed');
        return tree;
    };
}
function addBootstrapFiles() {
    return (tree, context) => {
        context.logger.debug("Adding bootstrap files");
        return schematics_1.chain([
            schematics_1.mergeWith(schematics_1.apply(schematics_1.url("./assets"), [schematics_1.move("./src/assets")])),
            schematics_1.mergeWith(schematics_1.apply(schematics_1.url("./icon"), [schematics_1.move("./")]))
        ])(tree, context);
    };
}
function getAngularJsonValue(tree) {
    const angularJsonAst = util_1.parseJsonAtPath(tree, "./angular.json");
    return angularJsonAst.value;
}
function getProject(angularJsonValue) {
    return angularJsonValue.defaultProject;
}
function modifyAngularJson(options) {
    return (tree, context) => {
        if (tree.exists("./angular.json")) {
            const angularJsonVal = getAngularJsonValue(tree);
            const project = getProject(angularJsonVal);
            const projectStylesOptionsJson = angularJsonVal["projects"][project]["architect"]["build"]["options"];
            const projectStylesTestJson = angularJsonVal["projects"][project]["architect"]["test"]["options"];
            const styles = [
                "src/assets/vendor.scss"
            ];
            if (options.removeStyles) {
                projectStylesOptionsJson["styles"] = styles;
                projectStylesTestJson["styles"] = styles;
            }
            else {
                Array.prototype.push.apply(projectStylesOptionsJson["styles"], styles);
                Array.prototype.push.apply(projectStylesTestJson["styles"], styles);
            }
            context.logger.debug(`Adding bootstrap scss override in angular.json style`);
            return tree.overwrite("./angular.json", JSON.stringify(angularJsonVal, null, 2));
        }
        else {
            throw new schematics_1.SchematicsException("angular.json not found");
        }
    };
}
//# sourceMappingURL=index.js.map